==> mythtv_0.16.orig.tar.gz: mythtv-0.16/themes/themestrings.h <==
void strings_null() {
    ThemeUI::tr("Scheduled Recordings:");
    ThemeUI::tr("Show  (1) All  (2) Important");
    ThemeUI::tr("Showing:");
    ThemeUI::tr("You Haven't Scheduled Any Programs To Be Recorded");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Program Guide' or 'Program Finder'");
    ThemeUI::tr("Channel Recording Priorities");
    ThemeUI::tr("(1) Sort by Channel    (2) Sort by Priority");
    ThemeUI::tr("Priority:");
    ThemeUI::tr("You Haven't Scheduled Any Programs To Be Recorded");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Program Guide' or 'Program Finder'");
    ThemeUI::tr("Program Recording Priorities");
    ThemeUI::tr("Priority");
    ThemeUI::tr("Final Priority");
    ThemeUI::tr("(1) Sort by Title    (2) Sort by Priority");
    ThemeUI::tr("Record Type:");
    ThemeUI::tr("[");
    ThemeUI::tr("]");
    ThemeUI::tr("Channel:");
    ThemeUI::tr("[");
    ThemeUI::tr("]");
    ThemeUI::tr("Priority:");
    ThemeUI::tr("[");
    ThemeUI::tr("]  = ");
    ThemeUI::tr("You Haven't Scheduled Any Programs To Be Recorded");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Program Guide' or 'Program Finder'");
    ThemeUI::tr("Select a recording to permanently delete:");
    ThemeUI::tr("Select a recording to view:");
    ThemeUI::tr("Sorry, No Recordings Available");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Schedule a Recording' from the Main Menu");
    ThemeUI::tr("(4) Program Guide   **(6) Program Finder **");
    ThemeUI::tr("Select a letter...");
    ThemeUI::tr("Pick the letter in which the show starts with, then hit ENTER or the right arrow");
    ThemeUI::tr("Select a program...");
    ThemeUI::tr("Select the title of the program you wish to find. When finished return with the left arrow key. Hitting 'info' will allow you to setup recording options.");
    ThemeUI::tr("No Programs");
    ThemeUI::tr("There are no available programs under this search. Please select another search.");
    ThemeUI::tr("Program Listings");
    ThemeUI::tr("No listings found for this program. ");
}

==> mythtv_0.17.orig.tar.gz: mythtv-0.17/themes/themestrings.h <==
void strings_null() {
    ThemeUI::tr("Scheduled Recordings:");
    ThemeUI::tr("Show  (1) All  (2) Important");
    ThemeUI::tr("Showing:");
    ThemeUI::tr("You Haven't Scheduled Any Programs To Be Recorded");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Program Guide' or 'Program Finder'");
    ThemeUI::tr("Channel Recording Priorities");
    ThemeUI::tr("(1) Sort by Channel    (2) Sort by Priority");
    ThemeUI::tr("Source:");
    ThemeUI::tr("Priority:");
    ThemeUI::tr("You Haven't Scheduled Any Programs To Be Recorded");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Program Guide' or 'Program Finder'");
    ThemeUI::tr("Program Recording Priorities");
    ThemeUI::tr("Priority");
    ThemeUI::tr("Final Priority");
    ThemeUI::tr("(1) Sort by Title    (2) Sort by Priority    (4) Sort by Type");
    ThemeUI::tr("(1) Sort by Channel    (2) Sort by Priority");
    ThemeUI::tr("Record Type:");
    ThemeUI::tr("Channel:");
    ThemeUI::tr("Priority:");
    ThemeUI::tr("You Haven't Scheduled Any Programs To Be Recorded");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Program Guide' or 'Program Finder'");
    ThemeUI::tr("Select a recording to permanently erase");
    ThemeUI::tr("Select a recording to watch");
    ThemeUI::tr("Select a recording to permanently erase:");
    ThemeUI::tr("Select a recording to watch:");
    ThemeUI::tr("Select a recording to permanently erase.");
    ThemeUI::tr("Select a recording to watch.");
    ThemeUI::tr("Sorry, No Recordings Available");
    ThemeUI::tr("To schedule a recording, exit this screen and");
    ThemeUI::tr("Select 'Schedule a Recording' from the Main Menu");
    ThemeUI::tr("(4) Program Guide   **(6) Program Finder **");
    ThemeUI::tr("Select a letter...");
    ThemeUI::tr("Pick the letter in which the show starts with, then press SELECT or the right arrow");
    ThemeUI::tr("Select a program...");
    ThemeUI::tr("Select the title of the program you wish to find. When finished return with the left arrow key. Press SELECT to schedule a recording.");
    ThemeUI::tr("No Programs");
    ThemeUI::tr("There are no available programs under this search. Please select another search.");
    ThemeUI::tr("Program Listings");
    ThemeUI::tr("No listings found for this program. ");
    ThemeUI::tr("Airdate:");
    ThemeUI::tr("Channel:");
    ThemeUI::tr("Description:");
    ThemeUI::tr("System Status - Select a category to view the status");
    ThemeUI::tr("This screen displays the status of various system components");
}
